@@ -6,7 +6,7 @@
  *  @file     vacc.h
  *  @ingroup  Vacc
  *  @brief    Contains declarations for class Vacc
- *  @version  $Id: vacc.h 1350 2009-02-12 00:38:48Z yhuang01 $
+ *  @version  $Id: vacc.h 1366 2009-04-22 18:37:13Z sdg0919 $
  *  @author   Nathan A. Baker
  *
  *  @attention
@@ -81,7 +81,7 @@ struct sVaccSurf {
     double *xpts;  /**< Array of point x-locations */
     double *ypts;  /**< Array of point y-locations */
     double *zpts;  /**< Array of point z-locations */
-    int *bpts;  /**< Array of booleans indicating whether a point is (1) or is
+    char *bpts;  /**< Array of booleans indicating whether a point is (1) or is
                  * not (0) part of the surface */
     double area;  /**< Area spanned by these points */
     int npts;  /**< Length of thee->xpts, ypts, zpts arrays */
