@@ -3,7 +3,7 @@
  *  @ingroup MGparm
  *  @author  Nathan Baker
  *  @brief   Class MGparm methods
- *  @version $Id: mgparm.c 1251 2008-03-30 22:32:00Z sobolevnrm $
+ *  @version $Id: mgparm.c 1350 2009-02-12 00:38:48Z yhuang01 $
  *  @attention
  *  @verbatim
  *
@@ -16,8 +16,8 @@
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2008, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2008.  Nathan A. Baker
+ * Copyright (c) 2002-2009, Washington University in St. Louis.
+ * Portions Copyright (c) 2002-2009.  Nathan A. Baker
  * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
  * Portions Copyright (c) 1995.  Michael Holst
  *
@@ -58,7 +58,7 @@
 #include "apbs/mgparm.h"
 #include "apbs/vstring.h"
 
-VEMBED(rcsid="$Id: mgparm.c 1251 2008-03-30 22:32:00Z sobolevnrm $")
+VEMBED(rcsid="$Id: mgparm.c 1350 2009-02-12 00:38:48Z yhuang01 $")
 
 #if !defined(VINLINE_MGPARM)
 
@@ -444,7 +444,7 @@ keyword!\n", tok);
 VPRIVATE Vrc_Codes MGparm_parseCHGM(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
-    int ti;
+    Vchrg_Meth ti;
 
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (sscanf(tok, "%d", &ti) == 1) {
@@ -579,11 +579,12 @@ VPRIVATE Vrc_Codes MGparm_parseGAMMA(MGparm *thee, Vio *sock) {
 	
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
 	Vnm_print(2, "parseMG:  GAMMA keyword deprecated!\n");
-	Vnm_print(2, "parseMG:  Please see new APOLAR documentation.\n");
+	Vnm_print(2, "parseMG:  If you are using PyMOL or VMD and still seeing this message,\n");
+	Vnm_print(2, "parseMG:  please contact the developers of those programs regarding this message.\n");
 	return VRC_SUCCESS;
 	
 VERROR1:
-        Vnm_print(2, "parseMG:  ran out of tokens!\n");
+	Vnm_print(2, "parseMG:  ran out of tokens!\n");
 	return VRC_WARNING;
 }
 
@@ -883,11 +884,11 @@ keyword!\n", tok);
         return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parseUSEAQUA(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseUSEAQUA(MGparm *thee, Vio *sock) {
     Vnm_print(0, "NOsh: parsed useaqua\n");
     thee->useAqua = 1;
     thee->setUseAqua = 1;
-    return 1;
+    return VRC_SUCCESS;
 }
 
 VPUBLIC Vrc_Codes MGparm_parseToken(MGparm *thee, char tok[VMAX_BUFSIZE], 
