@@ -2,7 +2,7 @@
  *  @file    valist.c
  *  @author  Nathan Baker
  *  @brief   Class Valist methods
- *  @version $Id: valist.c 1350 2009-02-12 00:38:48Z yhuang01 $
+ *  @version $Id: valist.c 1393 2009-08-26 16:00:23Z yhuang01 $
  *  @attention
  *  @verbatim
  *
@@ -54,11 +54,11 @@
 #include "apbscfg.h"
 #include "apbs/valist.h"
 
-VEMBED(rcsid="$Id: valist.c 1350 2009-02-12 00:38:48Z yhuang01 $")
+VEMBED(rcsid="$Id: valist.c 1393 2009-08-26 16:00:23Z yhuang01 $")
 
-VPRIVATE char *Valist_whiteChars = " \t\n";
+VPRIVATE char *Valist_whiteChars = " \t\r\n";
 VPRIVATE char *Valist_commChars  = "#%";
-VPRIVATE char *Valist_xmlwhiteChars = " \t\n<>";
+VPRIVATE char *Valist_xmlwhiteChars = " \t\r\n<>";
 
 #if !defined(VINLINE_VATOM)
 
@@ -649,6 +649,7 @@ VPUBLIC Vrc_Codes Valist_readPQR(Valist *thee, Vparam *params, Vio *sock) {
             if (Valist_readPDB_throughXYZ(thee, sock, &serial, atomName, 
                         resName, &resSeq, &x, &y, &z) == VRC_FAILURE) {
                 Vnm_print(2, "Valist_readPQR:  Error parsing atom %d!\n",serial);
+                Vnm_print(2, "Please double check this atom in the pqr file, e.g., make sure there are no concatenated fields.\n");
                 return VRC_FAILURE;
             }
 
@@ -656,6 +657,7 @@ VPUBLIC Vrc_Codes Valist_readPQR(Valist *thee, Vparam *params, Vio *sock) {
             if (Valist_readPDBChargeRadius(thee, sock, &charge, &radius) == VRC_FAILURE) {
                 Vnm_print(2, "Valist_readPQR:  Error parsing atom %d!\n", 
                           serial);
+                Vnm_print(2, "Please double check this atom in the pqr file, e.g., make sure there are no concatenated fields.\n");
                 return VRC_FAILURE;
             }
 
